# torus-cli

## Description

Command line interface for `torus-engine`: showcases the various functionality of the ASCII rendering engine.

## Install

### Download using pip

Open your terminal and type:

> `pip install torus-cli`

You can find more information on the package on PyPI by clicking [here](https://pypi.org/project/torus-cli/#description).

### Launch the CLI

In your terminal, you can simply launch `main.py`as follow:

> `cd torus-cli`
> `python3 src/toruscli/main.py`

And the program will laucnh in the current terminal window.

#### Help

While the program is running, you can control several aspects of the scene. To know more about what you can do, run:

> `python3 src/toruscli/main.py -h`

## 🛠 Improvments
Feel free to create an issue or a pull request in case you find bugs or want to add a feature!